@@ -252,73 +252,6 @@ SEXP distInt(SEXP XX, SEXP N, SEXP Genes) {
   return Dist;
 }
 
-/*
-
-SEXP GetChar(SEXP N, SEXP Choice, SEXP Shorter, SEXP Beep, SEXP Show) {  
-    int i, j, 
-      start = NA_INTEGER,
-      milli = 500,
-      len = length(Choice), 
-      n = INTEGER(N)[0],
-      nline = 100;
-  bool shorter = LOGICAL(Shorter)[0],
-      piep = LOGICAL(Beep)[0],
-      show = LOGICAL(Show)[0];
-  char choice[256], *zk,
-      backspace = 127,
-      eof = 'e'; // crl-D, ^D
-  SEXP Zk;
-  
-  zk = (char*) MALLOC(sizeof(char) * (n+1));
-  if (len > 256) len = 256;  
-  for (i=0; i<len; i++) {
-      choice[i] = CHAR(STRING_ELT(Choice, i))[0];
-  }
- 
-  system("/bin/stty cbreak -echo iuclc"); // or "stty raw" 
-  for (j=0; j<n; ) {
-   if (j % nline == 0) {
-       start = j;
-       if (show) {
-	   if (j != 0) PRINTF("\n");
-	   int m = n-j;
-	   if (m > nline) m = nline;
-	   for (i=0; i<m; i++) if (i % 20 == 19) PRINTF(":"); else PRINTF(".");
-	   for (i=0; i<m; i++) PRINTF("\b");
-       }
-   }
-
-    zk[j] = getchar();
-    if (zk[j] == eof && shorter) break;
-    if (zk[j] == backspace && j>start) {
-      j--;
-      PRINTF("\b \b");
-      continue;
-    }
-    for (i=0; i<len; i++)
-      if (zk[j] == choice[i]) break;
-    if (i < len) {
-	if (show) PRINTF("%c", zk[j], n-1-j);
-        j++; 
-    } else {
-	if (piep) PRINTF("beep does not work.\n"); // beep();
-    }
-  }
-//  beep();
-  if (show) {
-      PRINTF("\n");
-      sleepMilli(&milli);
-  }
-  system("/bin/stty -cbreak echo -iuclc");
-  zk[j] = '\0';
-  PROTECT(Zk = allocVector(STRSXP, 1));
-  SET_STRING_ELT(Zk, 0, mkChar(zk));
-  UNPROTECT(1);      
-  return Zk;
-}
-
-*/
-
 
 SEXP vectordist(SEXP V, SEXP DIAG){
   bool notdiag = !LOGICAL(DIAG)[0];
@@ -351,62 +284,6 @@ SEXP vectordist(SEXP V, SEXP DIAG){
   return DIST;
 }
 
-static int ORDERDIM;
-static double *ORDERD;
-static int *ORDERDINT;
-
-typedef bool (*vergleich)(int, int);
-vergleich SMALLER=NULL, GREATER=NULL;
-
-bool smaller(int i, int j)
-{
-  double *x, *y;
-  int d;
-  x = ORDERD + i * ORDERDIM;
-  y = ORDERD + j * ORDERDIM;
-  for(d=0; d<ORDERDIM; d++)
-     if (x[d] != y[d]) return x[d] < y[d];
-  return false;
-}
-
-bool greater(int i, int j)
-{
-  double *x, *y;
-  int d;
-  x = ORDERD + i * ORDERDIM;
-  y = ORDERD + j * ORDERDIM;
-  for(d=0; d<ORDERDIM; d++)
-    if (x[d] != y[d]) return x[d] > y[d];
-  return false;
-}
-
-bool smallerInt(int i, int j)
-{
-  int *x, *y;
-  int d;
-  x = ORDERDINT + i * ORDERDIM;
-  y = ORDERDINT + j * ORDERDIM;
-  for(d=0; d<ORDERDIM; d++) {
-    if (x[d] != y[d]) {
-     return x[d] < y[d];
-    }
-  }
-  return false;
-}
-
-
-
-bool greaterInt(int i, int j)
-{
-  int *x, *y;
-  int d;
-  x = ORDERDINT + i * ORDERDIM;
-  y = ORDERDINT + j * ORDERDIM;
-  for(d=0; d<ORDERDIM; d++)
-    if (x[d] != y[d]) return x[d] > y[d];
-  return false;
-}
-
 int is_positive_definite(double *C, int dim) {
     int err,
 	bytes = sizeof(double) * dim * dim;
@@ -418,87 +295,6 @@ int is_positive_definite(double *C, int dim) {
   return(err == 0);
 }
 
-void order(int *pos, int start, int end) {
-  int randpos, pivot, left, right, pivotpos, swap;
-  
-  if( start < end ) {   
-    //Get RNGstate();randpos = start + (int) (UNIFORM_RANDOM * (end-start+1)); PutRNGstate(); // use Get/Put RNGstate with great care !!
-    randpos = (int) (0.5 * (start + end));
-    pivot = pos[randpos];
-    pos[randpos] = pos[start];
-    pos[start] = pivot;
-    
-    pivotpos=start; 
-    left = start;
-    right=end+1;   
-    while (left < right) {      
-      //printf("order > %ld start=%d %d left=%d %d %d pivot=%d\n", pos, start, end, left, right, pos[left], pivot);
-      while (++left < right && SMALLER(pos[left], pivot)) {
-	pivotpos++;
-      }
-      while (--right > left && GREATER(pos[right], pivot));      
-      if (left < right) {
-	swap=pos[left]; pos[left]=pos[right]; pos[right]=swap;
-	pivotpos++;
-      }
-    }
-    pos[start] = pos[pivotpos];
-    pos[pivotpos] = pivot;
-    order(pos, start, pivotpos-1 );
-    order(pos, pivotpos + 1, end );
-  }
-}
-
-void ordering(double *d, int len, int dim, int *pos) 
-{
-  /* quicksort algorithm, slightly modified:
-     does not sort the data, but d[pos] will be ordered 
-     NOTE: pos must have the values 0,1,2,...,start-end !
-     (orderdouble is a kind of sorting pos according to
-     the variable d)
-  */  
-  int i;
-
-  for (i=0; i<len;i++) pos[i]=i;
-  ORDERD = d;
-  ORDERDIM = dim;
-  SMALLER = smaller;
-  GREATER = greater;
-  order(pos, 0, len-1);
-}
-
-
-void Ordering(double *d, int *len, int *dim, int *pos) 
-{
-  int i;
-  for (i=0; i<*len; i++) pos[i]=i;
-  ORDERD = d;
-  ORDERDIM = *dim;
-  SMALLER = smaller;
-  GREATER = greater;
-  order(pos, 0, *len-1 );
-}
-
-
-void orderingInt(int *d, int len, int dim, int *pos) 
-{
-  /* quicksort algorithm, slightly modified:
-     does not sort the data, but d[pos] will be ordered 
-     NOTE: pos must have the values 0,1,2,...,start-end !
-     (orderdouble is a kind of sorting pos according to
-     the variable d)
-  */  
-  
- 
-  int i;
-  for (i=0; i<len;i++) pos[i]=i;
-  ORDERDINT = d;
-  ORDERDIM = dim;
-  SMALLER = smallerInt;
-  GREATER = greaterInt; 
-  order(pos, 0, len-1);
-}
-
 
 int xMatch(char *name, char **list, unsigned int llen)  {
   unsigned int ln, nr;
